@@ -41,8 +41,6 @@
 
 #define SONNETCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(SONNETCORE_NO_DEPRECATED) && !defined(SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define SONNETCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef SONNETCORE_NO_DEPRECATED
-#  define SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef SONNETCORE_NO_DEPRECATED_WARNINGS
 #  define SONNETCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define SONNETCORE_DEPRECATED_WARNINGS_SINCE SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define SONNETCORE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define SONNETCORE_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef SONNETCORE_DEPRECATED
-#  define SONNETCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define SONNETCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define SONNETCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
